@@ -14,6 +14,7 @@ print()
 
 test_txt = list(Path.cwd().glob("test*.txt"))
 test_dat = list(Path.cwd().glob("test*.dat"))
+test_out = list(Path.cwd().glob("test*.out"))
 
 args_1 = {
     "infile": test_txt,
@@ -61,6 +62,21 @@ args_3 = {
     "legend": True,
     "version": True,
 }
+args_4 = {
+    "infile": test_out,
+    "comments": None,
+    "delimiter": None,
+    "skip_header": 0,
+    "skip_footer": 0,
+    "usecols": (0, 1),
+    "size": [30, 20],
+    "x_limits": None,
+    "y_limits": None,
+    "scatter": False,
+    "color": False,
+    "legend": True,
+    "version": False,
+}
 
 
 def test_fnames():
@@ -136,6 +152,11 @@ def test_customize_run_2():
     assert True
 
 
+def test_customize_run_3():
+    bashplot.bashplot(fnames=test_out, args=args_4)
+    assert True
+
+
 @mock.patch("bashplot.bashplot.command_line_runner")
 def test_command_line_mock(command_line_runner):
     bashplot.command_line_runner()
